package com.ruoyi.business.service;

import java.util.List;
import com.ruoyi.business.domain.HwSceneMode;

/**
 * 场景类型Service接口
 *
 * @author YINQ
 * @date 2023-08-31
 */
public interface IHwSceneModeService
{
    /**
     * 查询场景类型
     *
     * @param sceneModeId 场景类型主键
     * @return 场景类型
     */
    public HwSceneMode selectHwSceneModeBySceneModeId(Long sceneModeId);

    /**
     * 查询场景类型列表
     *
     * @param hwSceneMode 场景类型
     * @return 场景类型集合
     */
    public List<HwSceneMode> selectHwSceneModeList(HwSceneMode hwSceneMode);

    /**
     * 新增场景类型
     *
     * @param hwSceneMode 场景类型
     * @return 结果
     */
    public int insertHwSceneMode(HwSceneMode hwSceneMode);

    /**
     * 修改场景类型
     *
     * @param hwSceneMode 场景类型
     * @return 结果
     */
    public int updateHwSceneMode(HwSceneMode hwSceneMode);

    /**
     * 批量删除场景类型
     *
     * @param sceneModeIds 需要删除的场景类型主键集合
     * @return 结果
     */
    public int deleteHwSceneModeBySceneModeIds(Long[] sceneModeIds);

    /**
     * 删除场景类型信息
     *
     * @param sceneModeId 场景类型主键
     * @return 结果
     */
    public int deleteHwSceneModeBySceneModeId(Long sceneModeId);
}
